@@ -19,17 +19,12 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: common.h,v 1.1.1.1 2002/09/12 01:08:33 cry0gen Exp $
+ *  $Id: common.h 605 2006-06-08 21:26:01Z stu $
  */
 
 #ifndef INCLUDED_common_h
 #define INCLUDED_common_h
 
-
-#ifndef NULL
-#define NULL 0
-#endif
-
 #ifdef TRUE
 #undef TRUE
 #endif
@@ -59,8 +54,4 @@
 
 #define IRCD_MAX(a, b)  ((a) > (b) ? (a) : (b))
 #define IRCD_MIN(a, b)  ((a) < (b) ? (a) : (b))
-
-/* Right out of the RFC */
-#define IRCD_BUFSIZE 512
-
 #endif /* INCLUDED_common_h */
