@@ -19,29 +19,20 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: parse.h,v 1.1.1.1 2002/09/12 01:08:38 cry0gen Exp $
+ *  $Id: parse.h 497 2006-05-27 23:32:21Z stu $
  */
 
-#ifndef INCLUDED_parse_h_h
-#define INCLUDED_parse_h_h
+#ifndef INCLUDED_parse_h
+#define INCLUDED_parse_h
 
 struct Message;
 struct Client;
 
-struct MessageHash
-{
-  char   *cmd;
-  struct Message      *msg;
-  struct MessageHash  *next;
-}; 
+extern void parse(struct Client *, char *, char *);
+extern void clear_tree_parse(void);
+extern void mod_add_cmd(struct Message *);
+extern void mod_del_cmd(struct Message *);
+extern struct Message *find_command(const char *);
+extern void report_messages(struct Client *);
 
-#define MAX_MSG_HASH  387
-
-extern  void    parse (struct Client *, char *, char *);
-extern  void    clear_hash_parse (void);
-extern  void    mod_add_cmd(struct Message *msg);
-extern  void    mod_del_cmd(struct Message *msg);
-extern  void    report_messages(struct Client *);
-extern void list_commands(struct Client *);
-
-#endif /* INCLUDED_parse_h_h */
+#endif /* INCLUDED_parse_h */
