@@ -19,13 +19,13 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: restart.h,v 1.1.1.1 2002/09/12 01:08:38 cry0gen Exp $
+ *  $Id: restart.h 605 2006-06-08 21:26:01Z stu $
  */
 
 #ifndef INCLUDED_restart_h
 #define INCLUDED_restart_h
 
-void restart(char *);
-void server_reboot(void);
+extern void restart(const char *);
+extern void server_die(const char *, int);
 
 #endif
