@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: s_conf.h 855 2007-04-09 16:53:20Z stu $
+ *  $Id: s_conf.h 956 2007-09-28 16:11:48Z tjfontaine $
  */
 
 #ifndef INCLUDED_s_conf_h
@@ -129,6 +129,7 @@ struct AccessItem
   char *           rsa_public_key_file;
   RSA *            rsa_public_key;
   struct EncCapability *cipher_preference;
+  char *certfp;
 #endif
   pcre *regexuser;
   pcre *regexhost;
@@ -535,7 +536,7 @@ extern void split_nuh(struct split_nuh_item *);
 extern struct ConfItem *find_matching_name_conf(ConfType, const char *,
                                                 const char *, const char *, int);
 extern struct ConfItem *find_exact_name_conf(ConfType, const char *,
-                                             const char *, const char *);
+                                             const char *, const char *, const char *);
 extern void delete_conf_item(struct ConfItem *);
 extern void report_confitem_types(struct Client *, ConfType, int);
 extern void yyerror(const char *);
