@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_message.c 722 2006-11-22 18:29:54Z stu $
+ *  $Id: m_message.c 946 2007-08-24 16:23:12Z swalsh $
  */
 
 #include "stdinc.h"
@@ -122,7 +122,7 @@ _moddeinit(void)
   mod_del_cmd(&notice_msgtab);
 }
 
-const char *_version = "$Revision: 722 $";
+const char *_version = "$Revision: 946 $";
 #endif
 
 /*
@@ -512,6 +512,12 @@ msg_channel(int p_or_n, const char *command, struct Client *client_p,
         sendto_one(source_p, form_str(ERR_CANTSENDREGONLY),
             ID_or_name(&me, client_p),
             ID_or_name(source_p, client_p), chptr->chname);
+
+      if(chptr->mode.mode & MODE_OPMODERATED)
+      {
+        msg_channel_flags(p_or_n, command, client_p, source_p, chptr, CHFL_CHANOP,
+            text);
+      }
     }
   }
 }
