@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_nick.c 790 2007-02-15 20:43:11Z stu $
+ *  $Id: m_nick.c 942 2007-08-24 15:10:36Z swalsh $
  */
 
 #include "stdinc.h"
@@ -46,6 +46,7 @@
 #include "common.h"
 #include "packet.h"
 #include "irc_getaddrinfo.h"
+#include "channel_mode.h"
 
 static void m_nick(struct Client *, struct Client *, int, char **);
 static void mr_nick(struct Client *, struct Client *, int, char **);
@@ -94,7 +95,7 @@ _moddeinit(void)
   mod_del_cmd(&uid_msgtab);
 }
 
-const char *_version = "$Revision: 790 $";
+const char *_version = "$Revision: 942 $";
 #endif
 
 /* mr_nick()
@@ -233,6 +234,24 @@ m_nick(struct Client *client_p, struct Client *source_p,
     return;
   }
 
+  if(!IsOper(source_p))
+  {
+    struct Channel *chptr;
+    dlink_node *cptr;
+
+    DLINK_FOREACH(cptr, source_p->channel.head)
+    {
+      chptr = ((struct Membership *) cptr->data)->chptr;
+
+      if(can_send(chptr, source_p, cptr->data) == CAN_SEND_NO)
+      {
+        sendto_one(source_p, form_str(ERR_NONICKWHILEBAN), me.name, parv[0],
+            chptr->chname);
+        return;
+      }
+    }
+  }
+
   if ((target_p = find_client(nick)))
   {
     /* If(target_p == source_p) the client is changing nicks between
@@ -712,9 +731,9 @@ nick_from_server(struct Client *client_p, struct Client *source_p, int parc,
       {
         flag = user_modes[(unsigned char)*m];
         if (!(source_p->umodes & UMODE_INVISIBLE) && (flag & UMODE_INVISIBLE))
-	  Count.invisi++;
+          Count.invisi++;
         if (!(source_p->umodes & UMODE_OPER) && (flag & UMODE_OPER))
-	  Count.oper++;
+          Count.oper++;
 
         source_p->umodes |= flag & SEND_UMODES;
         m++;
