@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_challenge.c 605 2006-06-08 21:26:01Z stu $
+ *  $Id: m_challenge.c 956 2007-09-28 16:11:48Z tjfontaine $
  */
 
 #include "stdinc.h"
@@ -61,7 +61,7 @@ _moddeinit(void)
   mod_del_cmd(&challenge_msgtab);
 }
 
-const char *_version = "$Revision: 605 $";
+const char *_version = "$Revision: 956 $";
 #endif
 
 /*
@@ -105,7 +105,7 @@ m_challenge(struct Client *client_p, struct Client *source_p,
      
     if ((conf = find_exact_name_conf(OPER_TYPE,
 				     source_p->localClient->auth_oper,
-				     source_p->username, source_p->host
+				     source_p->username, source_p->host, source_p->certfp
 				   )) == NULL)
     {
       sendto_one (source_p, form_str(ERR_NOOPERHOST), me.name, parv[0]);
@@ -160,7 +160,7 @@ m_challenge(struct Client *client_p, struct Client *source_p,
   if(aconf == NULL)
   {
     sendto_one (source_p, form_str(ERR_NOOPERHOST), me.name, parv[0]);
-    conf = find_exact_name_conf(OPER_TYPE, parv[1], NULL, NULL);
+    conf = find_exact_name_conf(OPER_TYPE, parv[1], NULL, NULL, NULL);
     failed_challenge_notice(source_p, parv[1], (conf != NULL)
                             ? "host mismatch" : "no oper {} block");
     log_oper_action(LOG_FAILED_OPER_TYPE, source_p, "%s\n", parv[1]);
