@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_oper.c 605 2006-06-08 21:26:01Z stu $
+ *  $Id: m_oper.c 956 2007-09-28 16:11:48Z tjfontaine $
  */
 
 #include "stdinc.h"
@@ -64,7 +64,7 @@ _moddeinit(void)
   mod_del_cmd(&oper_msgtab);
 }
 
-const char *_version = "$Revision: 605 $";
+const char *_version = "$Revision: 956 $";
 #endif
 
 /*
@@ -96,7 +96,7 @@ m_oper(struct Client *client_p, struct Client *source_p,
   if ((conf = find_password_conf(name, source_p)) == NULL)
   {
     sendto_one(source_p, form_str(ERR_NOOPERHOST), me.name, source_p->name);
-    conf = find_exact_name_conf(OPER_TYPE, name, NULL, NULL);
+    conf = find_exact_name_conf(OPER_TYPE, name, NULL, NULL, NULL);
     failed_oper_notice(source_p, name, (conf != NULL) ?
                        "host mismatch" : "no oper {} block");
     log_oper_action(LOG_FAILED_OPER_TYPE, source_p, "%s\n", name);
@@ -157,15 +157,15 @@ find_password_conf(const char *name, struct Client *source_p)
   struct ConfItem *conf = NULL;
 
   if ((conf = find_exact_name_conf(OPER_TYPE,
-				   name, source_p->username, source_p->host
-				   )) != NULL)
+          name, source_p->username, source_p->host, source_p->certfp)) 
+      != NULL)
   {
     return(conf);
   }
 
   if ((conf = find_exact_name_conf(OPER_TYPE,
-				   name, source_p->username,
-				   source_p->sockhost)) != NULL)
+          name, source_p->username, source_p->sockhost, source_p->certfp)) 
+      != NULL)
   {
     return(conf);
   }
