@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_stats.c 845 2007-02-20 20:43:32Z weasel $
+ *  $Id: m_stats.c 957 2007-10-02 13:13:58Z tjfontaine $
  */
 
 #include "stdinc.h"
@@ -67,7 +67,7 @@ struct Message stats_msgtab = {
 };
 
 #ifndef STATIC_MODULES
-const char *_version = "$Revision: 845 $";
+const char *_version = "$Revision: 957 $";
 static struct Callback *stats_cb;
 
 static void *
@@ -992,15 +992,12 @@ stats_auth(struct Client *source_p)
     struct AccessItem *aconf;
 
     if (MyConnect(source_p))
-      aconf = find_conf_by_address(source_p->host,
-                                   &source_p->ip,
-				   CONF_CLIENT,
-				   source_p->aftype,
-				   source_p->username,
-                                   source_p->localClient->passwd);
+      aconf = find_conf_by_address(source_p->host, &source_p->ip,
+          CONF_CLIENT, source_p->aftype, source_p->username,
+          source_p->localClient->passwd, source_p->certfp);
     else
       aconf = find_conf_by_address(source_p->host, NULL, CONF_CLIENT,
-                                   0, source_p->username, NULL);
+          0, source_p->username, NULL, source_p->certfp);
 
     if (aconf == NULL)
       return;
@@ -1033,14 +1030,11 @@ stats_tklines(struct Client *source_p)
     struct AccessItem *aconf;
 
     if (MyConnect(source_p))
-      aconf = find_conf_by_address(source_p->host,
-                                   &source_p->ip,
-				   CONF_KILL,
-				   source_p->aftype,
-				   source_p->username, NULL);
+      aconf = find_conf_by_address(source_p->host, &source_p->ip,
+          CONF_KILL, source_p->aftype, source_p->username, NULL, NULL);
     else
       aconf = find_conf_by_address(source_p->host, NULL, CONF_KILL,
-                                   0, source_p->username, NULL);
+          0, source_p->username, NULL, NULL);
 
     if (aconf == NULL)
       return;
@@ -1076,14 +1070,11 @@ stats_klines(struct Client *source_p)
 
     /* search for a kline */
     if (MyConnect(source_p))
-      aconf = find_conf_by_address(source_p->host,
-                                   &source_p->ip,
-				   CONF_KILL,
-				   source_p->aftype,
-				   source_p->username, NULL);
+      aconf = find_conf_by_address(source_p->host, &source_p->ip,
+          CONF_KILL, source_p->aftype, source_p->username, NULL, NULL);
     else
       aconf = find_conf_by_address(source_p->host, NULL, CONF_KILL,
-                                   0, source_p->username, NULL);
+          0, source_p->username, NULL, NULL);
 
     if (aconf == NULL)
       return;
@@ -1141,6 +1132,9 @@ stats_operedup(struct Client *source_p)
     if(!IsOper(target_p))
       continue;
 
+    if(IsService(target_p))
+      continue;
+
     oper_count++;
     if(MyClient(target_p))
     {
