@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_xline.c 862 2007-04-10 18:23:16Z stu $
+ *  $Id: m_xline.c 924 2007-08-21 19:56:50Z swalsh $
  */
 
 #include "stdinc.h"
@@ -59,7 +59,7 @@ static void write_xline(struct Client *, char *, char *, time_t);
 static void remove_xline(struct Client *, char *);
 static int remove_txline_match(const char *);
 
-static void relay_xline(struct Client *, char *[]);
+static void relay_xline(struct Client *, char *[], int);
 
 struct Message xline_msgtab = {
   "XLINE", 0, 0, 2, 0, MFLG_SLOW, 0,
@@ -86,7 +86,7 @@ _moddeinit(void)
   mod_del_cmd(&unxline_msgtab);
 }
 
-const char *_version = "$Revision: 862 $";
+const char *_version = "$Revision: 924 $";
 #endif
 
 
@@ -131,8 +131,8 @@ mo_xline(struct Client *client_p, struct Client *source_p,
     /* if a given expire time is given, ENCAP it */
     if (tkline_time != 0)
       sendto_match_servs(source_p, target_server, CAP_ENCAP,
-			 "ENCAP %s XLINE %d %s 0 :%s",
-			 target_server, (int)tkline_time, gecos, reason);
+			 "ENCAP %s XLINE %s %s %d :%s",
+			 target_server, target_server, gecos, (int)tkline_time, reason);
     else
       sendto_match_servs(source_p, target_server, CAP_CLUSTER,
 			 "XLINE %s %s %d :%s",
@@ -146,7 +146,7 @@ mo_xline(struct Client *client_p, struct Client *source_p,
   {
     if (tkline_time != 0)
       cluster_a_line(source_p, "ENCAP", CAP_ENCAP, SHARED_XLINE,
-		     "XLINE %d %s 0 :%s", (int)tkline_time, gecos, reason);
+		     "XLINE %s %d :%s", gecos, (int)tkline_time, reason);
     else
       cluster_a_line(source_p, "XLINE", CAP_KLN, SHARED_XLINE,
 		     "%s 0 :%s", gecos, reason);
@@ -190,7 +190,7 @@ ms_xline(struct Client *client_p, struct Client *source_p,
   if (!valid_xline(source_p, parv[2], parv[4], 0))
     return;
 
-  relay_xline(source_p, parv);
+  relay_xline(source_p, parv, NO);
 }
 
 /* me_xline()
@@ -216,11 +216,11 @@ me_xline(struct Client *client_p, struct Client *source_p,
   if (!IsClient(source_p) || parc != 5)
     return;
 
-  relay_xline(source_p, parv);
+  relay_xline(source_p, parv, YES);
 }
 
 static void
-relay_xline(struct Client *source_p, char *parv[])
+relay_xline(struct Client *source_p, char *parv[], int encap)
 {
   struct ConfItem *conf;
   struct MatchItem *match_item;
@@ -231,9 +231,10 @@ relay_xline(struct Client *source_p, char *parv[])
   if (t_sec < 3)
     t_sec = 0;
 
-  sendto_match_servs(source_p, parv[1], CAP_CLUSTER,
-                     "XLINE %s %s %s :%s",
-                     parv[1], parv[2], parv[3], parv[4]);
+  if(!encap)
+    sendto_match_servs(source_p, parv[1], CAP_CLUSTER,
+        "XLINE %s %s %s :%s",
+        parv[1], parv[2], parv[3], parv[4]);
 
   if (!match(parv[1], me.name))
     return;
