@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: client.c 848 2007-02-22 19:31:31Z stu $
+ *  $Id: client.c 957 2007-10-02 13:13:58Z tjfontaine $
  */
 
 #include "stdinc.h"
@@ -789,7 +789,7 @@ exit_one_client(struct Client *source_p, const char *quitmsg)
     if (!MyConnect(source_p))
     {
       aconf = find_conf_by_address(source_p->host, &source_p->ip, 
-          CONF_CLIENT, source_p->aftype, source_p->username, NULL);
+          CONF_CLIENT, source_p->aftype, source_p->username, NULL, source_p->certfp);
 
       aclass = map_to_conf(aconf->class_ptr);
       assert(aclass != NULL);
@@ -1458,8 +1458,7 @@ change_local_nick(struct Client *client_p, struct Client *source_p, const char *
         strncasecmp(source_p->name, nick, NICKLEN) != 0)
     {
       ClearNickServReg(source_p);
-      sendto_one(source_p, ":%s MODE %s :-R", source_p->name,
-          source_p->name);
+      sendto_one(source_p, ":%s MODE %s :-R", nick, nick);
     }
 
     /*
