@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: s_gline.c 605 2006-06-08 21:26:01Z stu $
+ *  $Id: s_gline.c 957 2007-10-02 13:13:58Z tjfontaine $
  */
 
 #include "stdinc.h"
@@ -71,7 +71,7 @@ find_is_glined(const char *host, const char *user)
     piphost = NULL;
   }
 
-  aconf = find_conf_by_address(host, piphost, CONF_GLINE, t, user, NULL);
+  aconf = find_conf_by_address(host, piphost, CONF_GLINE, t, user, NULL, NULL);
   return(aconf);
 }
 
