@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: s_serv.c 796 2007-02-15 22:29:39Z stu $
+ *  $Id: s_serv.c 957 2007-10-02 13:13:58Z tjfontaine $
  */
 
 #include "stdinc.h"
@@ -50,6 +50,7 @@
 #include "s_conf.h"
 #include "s_serv.h"
 #include "s_log.h"
+#include "s_misc.h"
 #include "s_stats.h"
 #include "s_user.h"
 #include "send.h"
@@ -900,9 +901,18 @@ sendnick_TS(struct Client *client_p, struct Client *target_p)
 	       ubuf, target_p->username, target_p->host,
 	       target_p->servptr->name, target_p->info);
 
-  if(*target_p->realhost != '\0') 
-      sendto_one(client_p, "REALHOST %s %s", target_p->name,  
-              target_p->realhost);
+  if(!EmptyString(target_p->realhost)) 
+    sendto_one(client_p, "REALHOST %s %s", target_p->name, target_p->realhost);
+
+#ifdef HAVE_LIBCRYPTO
+  if(!EmptyString(target_p->certfp))
+  {
+    char buf[SHA_DIGEST_LENGTH*2+1];
+
+    base16_encode(buf, sizeof(buf), target_p->certfp, sizeof(target_p->certfp));
+    sendto_one(client_p, "CERTFP %s %s", target_p->name, buf);
+  }
+#endif
 
   if (IsConfAwayBurst((struct AccessItem *)map_to_conf(client_p->serv->sconf)))
     if (!EmptyString(target_p->away))
@@ -1799,14 +1809,14 @@ set_autoconn(struct Client *source_p, const char *name, int newval)
 
   if (name != NULL)
   {
-    conf = find_exact_name_conf(SERVER_TYPE, name, NULL, NULL);
+    conf = find_exact_name_conf(SERVER_TYPE, name, NULL, NULL, NULL);
     if (conf != NULL)
     {
       aconf = (struct AccessItem *)map_to_conf(conf);
       if (newval)
-	SetConfAllowAutoConn(aconf);
+        SetConfAllowAutoConn(aconf);
       else
-	ClearConfAllowAutoConn(aconf);
+        ClearConfAllowAutoConn(aconf);
 
       sendto_realops_flags(UMODE_ALL, L_ALL,
 			   "%s has changed AUTOCONN for %s to %i",
