@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: s_user.c 856 2007-04-09 16:59:04Z stu $
+ *  $Id: s_user.c 957 2007-10-02 13:13:58Z tjfontaine $
  */
 
 #include "stdinc.h"
@@ -109,7 +109,7 @@ unsigned int user_modes[256] =
   0,                  /* M */
   0,                  /* N */
   0,                  /* O */
-  0,                  /* P */
+  UMODE_SERVICE,      /* P */
   0,                  /* Q */
   UMODE_NICKSERVREG,  /* R */
   UMODE_GOD,          /* S */
@@ -586,7 +586,7 @@ register_remote_user(struct Client *client_p, struct Client *source_p,
   SetIpHash(source_p);
 
   aconf = find_conf_by_address(source_p->host, &source_p->ip,
-       CONF_CLIENT, source_p->aftype, source_p->username, NULL);
+       CONF_CLIENT, source_p->aftype, source_p->username, NULL, source_p->certfp);
   aclass = map_to_conf(aconf->class_ptr);
 
   cidr_limit_reached(1, &source_p->ip, aclass);
@@ -656,6 +656,14 @@ introduce_client(struct Client *client_p, struct Client *source_p)
                  ubuf, source_p->username, source_p->host,
                  source_p->servptr->name, source_p->info);
     }
+
+    if(!EmptyString(source_p->certfp))
+    {
+      char buf[SHA_DIGEST_LENGTH*2+1];
+
+      base16_encode(buf, sizeof(buf), source_p->certfp, sizeof(source_p->certfp));
+      sendto_one(uplink, "CERTFP %s %s", source_p->name, buf);
+    }
   }
   else
   {
@@ -680,6 +688,13 @@ introduce_client(struct Client *client_p, struct Client *source_p)
                    (unsigned long)source_p->tsinfo,
                    ubuf, source_p->username, source_p->host,
                    source_p->servptr->name, source_p->info);
+      if(!EmptyString(source_p->certfp))
+      {
+        char buf[SHA_DIGEST_LENGTH*2+1];
+
+        base16_encode(buf, sizeof(buf), source_p->certfp, sizeof(source_p->certfp));
+        sendto_one(server, "CERTFP %s %s", source_p->name, buf);
+      }
     }
   }
 }
@@ -1037,6 +1052,7 @@ set_user_mode(struct Client *client_p, struct Client *source_p,
         case '\n':
         case '\r':
         case 'R': /* Users not allowed to change +R */
+        case 'P': /* Or +P */
         case '\t':
           break;
 
@@ -1213,9 +1229,21 @@ user_welcome(struct Client *source_p)
 
 #ifdef HAVE_LIBCRYPTO
   if (source_p->localClient->fd.ssl != NULL)
+  {
     sendto_one(source_p, ":%s NOTICE %s :*** Connected securely via %s",
                me.name, source_p->name,
                ssl_get_cipher(source_p->localClient->fd.ssl));
+    if(!EmptyString(source_p->certfp))
+    {
+      char buf[SHA_DIGEST_LENGTH*2+1]; 
+
+      base16_encode(buf, SHA_DIGEST_LENGTH*2+1, source_p->certfp,
+          SHA_DIGEST_LENGTH);
+      sendto_one(source_p, 
+          ":%s NOTICE %s: *** Your client certificate fingerprint is: %s",
+          me.name, source_p->name, buf);
+    }
+  }
 #endif
 
   sendto_one(source_p, form_str(RPL_WELCOME), me.name, source_p->name, 
